@@ -4,7 +4,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our %SPEC;
 
@@ -52,35 +52,20 @@ App::ParseCPANChanges - Parse CPAN Changes file
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
 This distribution provides a simple command-line wrapper for
-L<CPAN::Changes>.
-
-=head1 SEE ALSO
-
-L<CPAN::Changes>
-
-=head1 AUTHOR
-
-Steven Haryanto <stevenharyanto@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Steven Haryanto.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+L<CPAN::Changes>. See L<parse-cpan-changes> for more details.
 
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 parse_cpan_changes(%args) -> [status, msg, result, meta]
 
+Parse CPAN Changes file.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -95,4 +80,45 @@ Return value:
 
 Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
 
+=head1 SEE ALSO
+
+L<CPAN::Changes>
+
+L<CPAN::Changes::Spec>
+
+An alternative way to manage your Changes using INI master format:
+L<Module::Metadata::Changes>.
+
+Dist::Zilla plugin to check your Changes before build:
+L<Dist::Zilla::Plugin::CheckChangesHasContent>,
+L<Dist::Zilla::Plugin::CheckChangeLog>.
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/App-ParseCPANChanges>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-App-ParseCPANChanges>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/Public/Dist/Display.html?Name=App-ParseCPANChanges
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 AUTHOR
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Steven Haryanto.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
